==> vtk-v2.0.x.zip: vtk-v2.0.x/pcmaker/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by pcmaker.rc
//
#define IDD_PCMAKER_DIALOG              102
#define IDR_MAINFRAME                   128
#define IDD_HELPDIALOG                  129
#define IDC_RADIO2                      1001
#define IDC_RADIO3                      1002
#define IDC_WHEREVTK                    1003
#define IDC_COMPILER                    1004
#define IDC_WHERECOMPILER               1005
#define IDC_WHEREJDK                    1006
#define IDC_WHEREBUILD                  1009
#define IDC_MSCOMP                      1010
#define IDC_BORLANDCOMP                 1011
#define IDC_Graphics                    1012
#define IDC_Imaging                     1013
#define IDC_Contrib                     1014
#define IDC_GenericComp                 1015
#define IDC_Debug                       1017
#define IDC_GEMSIO                      1018
#define IDC_WORKING                     1018
#define IDC_GEMSIP                      1019
#define IDC_GEMSVOLUME                  1020
#define IDC_CHECK5                      1021
#define IDC_PATENTED                    1022
#define IDC_PROGRESS1                   1024
#define IDC_LEAN                        1025
#define IDC_HELP1                       1026
#define IDC_EDIT1                       1027

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        130
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1028
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> vtk-v2.2.x.zip: vtk-v2.2.x/pcmaker/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by pcmaker.rc
//
#define IDD_PCMAKER_DIALOG              102
#define IDR_MAINFRAME                   128
#define IDD_HELPDIALOG                  129
#define IDD_ADVANCED                    130
#define IDC_RADIO2                      1001
#define IDC_RADIO3                      1002
#define IDC_WHEREVTK                    1003
#define IDC_COMPILER                    1004
#define IDC_WHERECOMPILER               1005
#define IDC_WHEREJDK                    1006
#define IDC_WHERETK                     1007
#define IDC_WHEREBUILD                  1009
#define IDC_MSCOMP                      1010
#define IDC_BORLANDCOMP                 1011
#define IDC_Graphics                    1012
#define IDC_Imaging                     1013
#define IDC_Contrib                     1014
#define IDC_GenericComp                 1015
#define IDC_Debug                       1017
#define IDC_GEMSIO                      1018
#define IDC_WORKING                     1018
#define IDC_GEMSIP                      1019
#define IDC_GEMSVOLUME                  1020
#define IDC_CHECK5                      1021
#define IDC_PATENTED                    1022
#define IDC_PROGRESS1                   1024
#define IDC_LEAN                        1025
#define IDC_HELP1                       1026
#define IDC_EDIT1                       1027
#define IDC_ADVANCED                    1027
#define IDC_INCREMENTAL                 1028
#define IDC_GEAE                        1029
#define IDC_DFA                         1030
#define IDC_WHERETCL                    1031
#define IDC_EXTRA_CFLAGS                1032
#define IDC_EXTRA_LINK_FLAGS            1033

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        131
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1033
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
